==> ssp-center-api-0.2.72.fangzhipeng-20180831.041141-7-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotInfoDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;

public class SlotInfoDto implements Serializable {

    private static final long serialVersionUID = -6317826864675855242L;

    //无屏蔽
    public static final int NO_SHIELD = 0;
    //行业屏蔽
    public static final int INDUSTRY_SHIELD = 1;
    //标签屏蔽
    public static final int TAG_SHIELD = 2;
    //活动屏蔽
    public static final int ACTIVITY_SHIELD = 3;
    //落地页屏蔽屏蔽
    public static final int LAND_URL_SHIELD = 4;
    // 落地页屏蔽标签
	public static final int PROMOTE_TAG_SHIELD = 5;

    //删除状态
    public static final int DELETE_STATUS = 0;
    //关闭状态
    public static final int CLOSE_STATUS = 1;
    //冻结状态
    public static final int FREEZE_STATUS = 2;
    //开启状态
    public static final int ENABLE_STATUS = 3;

    /**
     * 广告位ID
     */
    private Long slotId;
    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 广告位名称
     */
    private String slotName;

    /**
     * 广告位接入类型 0-互动广告 1-展示广告 null-兑吧广告位没有标识对应字段，所以传null
     */
    private Integer slotAccessType;

    private Integer status;

    private Integer type;

    private String shieldContent;

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getSlotName() {
        return slotName;
    }

    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getShieldContent() {
        return shieldContent;
    }

    public void setShieldContent(String shieldContent) {
        this.shieldContent = shieldContent;
    }

    public Integer getSlotAccessType() {
        return slotAccessType;
    }

    public void setSlotAccessType(Integer slotAccessType) {
        this.slotAccessType = slotAccessType;
    }

    @Override
    public String toString() {
        return org.apache.commons.lang.builder.ToStringBuilder.reflectionToString(this);
    }
}

==> ssp-center-api-0.2.74.fangzhipeng-20180928.030318-19-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/SlotInfoDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;

public class SlotInfoDto implements Serializable {

    private static final long serialVersionUID = -6317826864675855242L;

    //无屏蔽
    public static final int NO_SHIELD = 0;
    //行业屏蔽
    public static final int INDUSTRY_SHIELD = 1;
    //标签屏蔽
    public static final int TAG_SHIELD = 2;
    //活动屏蔽
    public static final int ACTIVITY_SHIELD = 3;
    //落地页屏蔽屏蔽
    public static final int LAND_URL_SHIELD = 4;
    // 落地页屏蔽标签
	public static final int PROMOTE_TAG_SHIELD = 5;

    //删除状态
    public static final int DELETE_STATUS = 0;
    //关闭状态
    public static final int CLOSE_STATUS = 1;
    //冻结状态
    public static final int FREEZE_STATUS = 2;
    //开启状态
    public static final int ENABLE_STATUS = 3;

    /**
     * 广告位ID
     */
    private Long slotId;
    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 广告位名称
     */
    private String slotName;

    /**
     * 广告位接入类型 0-互动广告 1-展示广告 null-兑吧广告位没有标识对应字段，所以传null
     */
    private Integer slotAccessType;

    private Integer status;

    private Integer type;

    private String shieldContent;

    /**
     * 广告位备注图片地址, 逗号分隔
     */
    private String remarkImg;

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getSlotName() {
        return slotName;
    }

    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getShieldContent() {
        return shieldContent;
    }

    public void setShieldContent(String shieldContent) {
        this.shieldContent = shieldContent;
    }

    public Integer getSlotAccessType() {
        return slotAccessType;
    }

    public void setSlotAccessType(Integer slotAccessType) {
        this.slotAccessType = slotAccessType;
    }

    public String getRemarkImg() {
        return remarkImg;
    }

    public void setRemarkImg(String remarkImg) {
        this.remarkImg = remarkImg;
    }

    @Override
    public String toString() {
        return org.apache.commons.lang.builder.ToStringBuilder.reflectionToString(this);
    }
}
